-------------------------------------------------------------------------------
-- Title      : Route Lookup Table
-- Project    : OCP compliant Network Adapter
-------------------------------------------------------------------------------
-- File       : RouteLookupTable.vhd
-- Author     : Juliana Pei Zhou
-- Company    : Informatics and Mathematical Modelling, TUD
-- Last update: 2004/09/05
-------------------------------------------------------------------------------
-- Description: Stores all the routepaths to other cores of the NoC. This table
-- is local the the NA and is different from one NA to another depending on the
-- location of the NA in the NoC. The table is populated at NA instantiation
-- time and will be static. 
-------------------------------------------------------------------------------

library ieee;
use ieee.std_logic_1164.all;
use ieee.std_logic_arith.all;
use ieee.std_logic_unsigned.all;
use work.types.all;
use ieee.numeric_std.all;

entity RouteLookupTable is
  port (address : in  std_logic_vector(7 downto 0);
        read_data : out std_logic_vector(15 downto 0));
end RouteLookupTable;

architecture behavioral of RouteLookupTable is

begin

  with address select
    read_data <=
    N&S&N&N&N&N&N&N when X"00",         -- 2000
    E&N&S&N&N&N&N&N when X"01",         -- 4800
    E&E&N&S&N&N&N&N when X"02",         -- 5200
    E&E&E&N&S&N&N&N when X"03",         -- 5480
    E&E&E&E&N&S&N&N when X"04",         -- 5520
-- SBA of this core is 05
    E&W&N&N&N&N&W&N when X"06",         -- 7000
    E&E&W&N&N&N&N&N when X"07",         -- 5C00
    E&E&E&W&N&N&N&N when X"08",         -- 5700
    E&E&E&E&W&N&N&N when X"09",         -- 55C0
    S&N&N&N&N&N&N&N when X"0A",         -- 8000
    S&E&W&N&N&N&N&N when X"0B",         -- 9C00
    S&E&E&W&W&W&W&W when X"0C",         -- 97FF  -- Network adapter SBA
    N&E&S&W&N&E&S&W when others;        -- 1B1B


end behavioral;

library ieee;
use ieee.std_logic_1164.all;
use ieee.std_logic_arith.all;
use ieee.std_logic_unsigned.all;
use work.types.all;
use ieee.numeric_std.all;

package RouteLookupTable_pkg is
  component RouteLookupTable
    port (
      address   : in  std_logic_vector(7 downto 0);
      read_data : out std_logic_vector(15 downto 0));
  end component;
end RouteLookupTable_pkg;
