library ieee;
use ieee.std_logic_1164.all;

package types is

-------------------------------------------------------------------------------
--
-------------------------------------------------------------------------------
  constant SBA_length       : integer := 8;
  constant routepath_length : integer := 16;  -- implements a simple 3x3
                                              -- network, max 4 hops. 


  constant MCmd_length      : integer := 3;
  constant MData_length     : integer := 32;
  constant MDataInfo_length : integer := 8;   -- Source Core Address (SBA)
  constant MAddr_length     : integer := 32;
  constant MFlag_length     : integer := 32;
  constant MReqInfo_length  : integer := 2;
  constant SData_length     : integer := 32;
  constant SDataInfo_length : integer := 32;  -- Contain Address of desination
                                              -- core.
  constant SResp_length     : integer := 2;
  constant NC_SBA  : std_logic_vector(7 downto 0) := X"0C";
  constant Master_SBA : std_logic_vector(7 downto 0) := X"05";
------------------------------------------------------------------------------
--
-------------------------------------------------------------------------------
  -- Direction encoding
  constant N : std_logic_vector(1 downto 0) := "00";
  constant E : std_logic_vector(1 downto 0) := "01";
  constant S : std_logic_vector(1 downto 0) := "10";
  constant W : std_logic_vector(1 downto 0) := "11";

  -- MCmd encoding
  subtype MCmd_type is std_logic_vector(2 downto 0);
  constant IDLE : MCmd_type := "000";
  constant WR   : MCmd_type := "001";
  constant RD   : MCmd_type := "010";
  constant RDEX : MCmd_type := "011";
  constant RDL  : MCmd_type := "100";
  constant WRNP : MCmd_type := "101";
  constant WRC  : MCmd_type := "110";
  constant BCST : MCmd_type := "111";

  -- SResp encoding
  subtype SResp_type is std_logic_vector(1 downto 0);
  constant NV        : SResp_type := "00";
  constant DVA       : SResp_type := "01";
  constant FAIL      : SResp_type := "10";
  constant ERR       : SResp_type := "11";
  
  -- Network Interface
  constant flit_size : integer    := 17;
  constant num_vc    : integer    := 8;  -- number of virtual channels
  constant chSelect  : integer    := 3;  -- number of channel control bits 

  -- vcScheduler priority queue encoding
  -- subtype priority is std_logic_vector(1 downto 0);
  -- constant BE_L : priority := "00";       -- lowest priority
  -- constant BE_H : priority := "01";
  -- constant GP   : priority := "10";
  -- constant GT   : priority := "11";       -- highest priority
  subtype priority is integer range 0 to 3;
  constant BE_L            : priority := 0;  -- lowest priority
  constant BE_H            : priority := 1;
  constant GP              : priority := 2;
  constant GT              : priority := 3;  -- highest priority
  -- vcScheduler Register File
  subtype RegAddr is integer range 0 to num_vc-1;
  type RegType is array(RegAddr) of priority;
  type vcRecord is record
                     data  : priority;
                     empty : std_logic;
                     pos   : integer range 0 to num_vc-1;
                   end record;
-------------------------------------------------------------------------------
--
-------------------------------------------------------------------------------

  -- Virtual Channel
  subtype flit_type is std_logic_vector(flit_size-1 downto 0);
  type channel_type is array (0 to num_vc-1) of flit_type;

  -- Packet Type
  constant max_no_flit_in_packet : integer := 9;
-- subtype packet_type is std_logic_vector(max_no_flit_in_packet*(flit_size-1)-1 downto 0);
  subtype flit_num is integer range 0 to max_no_flit_in_packet-1;
  type inflitRegType is array(flit_num) of std_logic_vector(flit_size -2 downto 0);
  type outflitRegType is array(flit_num) of std_logic_vector(flit_size -1 downto 0);

  -- Packet Type Encoding
  subtype Packet_Type is std_logic_vector(2 downto 0);
  constant Setup_Req     : Packet_Type                               := "000";
  constant Setup_Resp    : Packet_Type                               := "001";
  constant Teardown_Req  : Packet_Type                               := "010";
  constant Teardown_Resp : Packet_Type                               := "011";
  constant BE_Req        : Packet_Type                               := "100";
  constant BE_Resp       : Packet_Type                               := "101";
  constant GS_Req        : Packet_Type                               := "110";
  constant GS_Resp       : Packet_Type                               := "111";



end package types;


