library ieee;
use ieee.std_logic_1164.all;
use ieee.std_logic_arith.all;
use ieee.std_logic_unsigned.all;
use work.types.all;

entity compare is
  port (
    input1_D : in  std_logic_vector(1 downto 0);
    input1_P :	in std_logic_vector(num_vc-1 downto 0);
    input1_E :	 in bit_t;
    input2_D : in  std_logic_vector(1 downto 0);
    input2_P :	in std_logic_vector(num_vc-1 downto 0);
    input2_E :	 in bit_t;
    output_D : out  std_logic_vector(1 downto 0);
    output_P :	out std_logic_vector(num_vc-1 downto 0);
    output_E :	out bit_t);
end compare;

architecture structure of compare is
  signal value1  : integer;
  signal value2  : integer;
  signal counter : bit_t := '0';

begin  -- structure
  value1 <= conv_integer(unsigned(input1_D));
  value2 <= conv_integer(unsigned(input2_D));

  process (input1_D, input1_P, input1_E, input2_D,input2_P,input2_E,counter  )
  begin  -- process
    if input1_E = '1' and input2_E = '1' then
      output_D   <= input1_D;
      output_E  <= '1';
    else
      output_E  <= '0';
      if input1_E = '1' then
        output_D <= input2_D;
        output_P  <= input2_P;
      elsif input2_E = '1' then
        output_D <= input1_D;
        output_P  <= input1_P;
      elsif value1 < value2 then
        output_D <= input2_D;
        output_P  <= input2_P;
      elsif value1 > value2 then
        output_D <= input1_D;
        output_P  <= input1_P;
      elsif counter = '0' then
        output_D <= input1_D;
        output_P  <= input1_P;
        counter     <= not counter;
      else
        output_D <= input2_D;
        output_P  <= input2_P;
        counter     <= not counter;
      end if;
    end if;
  end process;
end structure;

library ieee;
use ieee.std_logic_1164.all;
use ieee.std_logic_arith.all;
use ieee.std_logic_unsigned.all;
use work.types.all;
package compare_pkg is
  component compare
    port (
      input1 : in  vcRecord;
      input2 : in  vcRecord;
      output : out vcRecord);
  end component;
end compare_pkg;
