library ieee;
use ieee.std_logic_1164.all;
use ieee.std_logic_arith.all;
use ieee.std_logic_unsigned.all;
use work.types.all;
use work.decap_pkg.all;
use work.ReqE2E_pkg.all;

entity decap_environment is
  port(
    clk        : in  std_logic;
    reset      : in  std_logic;
    SBA        : in  std_logic_vector(SBA_length-1 downto 0);
    -- Network Interface signals
    empty      : in  std_logic_vector(num_vc-1 downto 0);
    get        : out std_logic_vector(num_vc-1 downto 0);
    inChannels : in  channel_type
    );
end decap_environment;

architecture behavioral of decap_environment is



  signal inChSel_i          : std_logic_vector(chSelect-1 downto 0);
  signal inFlit_i           : std_logic_vector(flit_size-1 downto 0);
  signal routepath_i        : std_logic_vector(routepath_length-1 downto 0);
  signal MAddr_i            : std_logic_vector(MAddr_length-1 downto 0);
  signal MCmd_i             : std_logic_vector(MCmd_length-1 downto 0);
  signal packet_decode_i    : Packet_Type;
  signal MFlag_i            : std_logic_vector(MFlag_length-1 downto 0);
  signal MData_i            : std_logic_vector(MData_length-1 downto 0);
  signal MDataInfo_i        : std_logic_vector(MDataInfo_length-1 downto 0);
  signal Request_arrived_i  : std_logic;
  signal SResp_i            : std_logic_vector(SResp_length-1 downto 0);
  signal SData_i            : std_logic_vector(SData_length-1 downto 0);
  signal SDataInfo_i        : std_logic_vector(SDataInfo_length-1 downto 0);
  signal Response_arrived_i : std_logic;

begin  -- behavioral 

  Decapsulation : component Decap
    port map (
      clk              => clk,
      reset            => reset,
      SBA              => SBA,
      empty            => empty,
      get              => get,
      inChSel          => inChSel_i,
      inFlit           => inFlit_i,
      routepath        => routepath_i,
      MAddr            => MAddr_i,
      MCmd             => MCmd_i,
      packet_decode    => packet_decode_i,
      MFlag            => MFlag_i,
      MData            => MData_i,
      MDataInfo        => MDataInfo_i,
      Request_arrived  => Request_arrived_i,
      SResp            => SResp_i,
      SData            => SData_i,
      SDataInfo        => SDataInfo_i,
      Response_arrived => Response_arrived_i);



  Input_PortMux : process (reset,inChannels, inChsel_i)
  begin  -- process Input Port Mux
    if reset = '1' then
      inFlit_i <= (others => '0');
    else
      case inChSel_i is
        when "000" =>
          inFlit_i <= inChannels(0);
        when "001" =>
          inFlit_i <= inChannels(1);
        when "010" =>
          inFlit_i <= inChannels(2);
        when "011" =>
          inFlit_i <= inChannels(3);
        when "100" =>
          inFlit_i <= inChannels(4);
        when "101" =>
          inFlit_i <= inChannels(5);
        when "110" =>
          inFlit_i <= inChannels(6);
        when "111" =>
          inFlit_i <= inChannels(7);
        when others => null;
      end case;
    end if;
  end process Input_PortMux;


end behavioral;
