library ieee;
use ieee.std_logic_1164.all;
use ieee.std_logic_arith.all;
use ieee.std_logic_unsigned.all;
use ieee.numeric_std.all;
use work.types.all;
use work.Encap_pkg.all;
use work.Queue_pkg.all;
use work.Queue_Control_pkg.all;

entity encap_environment is
  port (
    clk              : in  std_logic;
    reset            : in  std_logic;
    -- Signal from ReqE2E
    packet_encode_In : in  Packet_Type;
    MCmd_In          : in  MCmd_type;
    MAddr_In         : in  std_logic_vector(MAddr_length-1 downto 0);
    MFlag_In         : in  std_logic_vector(MFlag_length-1 downto 0);
    MData_In         : in  std_logic_vector(MData_length-1 downto 0);
    MDataInfo_In     : in  std_logic_vector(MDataInfo_length-1 downto 0);
    request_phase    : in  std_logic;
    -- Signal to ReqE2E
    packet_sent_Out  : out std_logic;
    -- Signal from Connection ID Table
    InjID            : in  std_logic_vector(31 downto 0);
    -- Signal from Route Lookup Table
    routepath_In     : in  std_logic_vector(routepath_length-1 downto 0);
    -- Signal to and from Network Interface
    outChannels      : out channel_type;
    full             : in  std_logic_vector(num_vc-1 downto 0);
    put              : out std_logic_vector(num_vc-1 downto 0)
    );
end encap_environment;

architecture behavioral of encap_environment is

  -- Encap (to Queue Control)
  signal outChSel_i        : std_logic_vector(chSelect-1 downto 0);
  signal packet_sent_Out_i : std_logic;

  -- Encap (from Queue Control)
  signal hold_i : std_logic_vector(7 downto 0);

  -- Encap (to Queue)
  signal packet_i : outflitRegType;

  -- Queue (to Queue Control)
  signal ready : std_logic_vector(7 downto 0);

  -- Queue (from Queue Control)
  signal load : std_logic_vector(7 downto 0);


begin  -- behavioral

  Encap_Unit : Encap
    port map (
      clk              => clk,
      reset            => reset,
      packet_encode_In => packet_encode_In,
      MCmd_In          => MCmd_In,
      MAddr_In         => MAddr_In,
      MFlag_In         => MFlag_In,
      MData_In         => MData_In,
      MDataInfo_In     => MDataInfo_In,
      request_phase    => request_phase,
      packet_sent_Out  => packet_sent_Out_i,
      InjID            => InjID,
      routepath_In     => routepath_In,
      outChSel         => outChSel_i,
      packet           => packet_i,
      hold             => hold_i);
  packet_sent_Out <= packet_sent_Out_i;

  Queue_contol_Unit : Queue_Control
    port map (
      clk         => clk,
      reset       => reset,
      load        => load,
      ready       => ready,
      packet_sent => packet_sent_Out_i,
      outChSel    => outChSel_i,
      hold        => hold_i);


  Queue_zero : Queue
    port map (
      clk        => clk,
      reset      => reset,
      load       => load(0),
      flit_array => packet_i,
      outFlit    => outChannels(0),
      ready      => ready(0),
      full       => full(0),
      put        => put(0));

  Queue_one : Queue
    port map (
      clk        => clk,
      reset      => reset,
      load       => load(1),
      flit_array => packet_i,
      outFlit    => outChannels(1),
      ready      => ready(1),
      full       => full(1),
      put        => put(1));

  Queue_two : Queue
    port map (
      clk        => clk,
      reset      => reset,
      load       => load(2),
      flit_array => packet_i,
      outFlit    => outChannels(2),
      ready      => ready(2),
      full       => full(2),
      put        => put(2));

  Queue_three : Queue
    port map (
      clk        => clk,
      reset      => reset,
      load       => load(3),
      flit_array => packet_i,
      outFlit    => outChannels(3),
      ready      => ready(3),
      full       => full(3),
      put        => put(3));

  Queue_four : Queue
    port map (
      clk        => clk,
      reset      => reset,
      load       => load(4),
      flit_array => packet_i,
      outFlit    => outChannels(4),
      ready      => ready(4),
      full       => full(4),
      put        => put(4));

  Queue_five : Queue
    port map (
      clk        => clk,
      reset      => reset,
      load       => load(5),
      flit_array => packet_i,
      outFlit    => outChannels(5),
      ready      => ready(5),
      full       => full(5),
      put        => put(5));

  Queue_six : Queue
    port map (
      clk        => clk,
      reset      => reset,
      load       => load(6),
      flit_array => packet_i,
      outFlit    => outChannels(6),
      ready      => ready(6),
      full       => full(6),
      put        => put(6));

  Queue_seven : Queue
    port map (
      clk        => clk,
      reset      => reset,
      load       => load(7),
      flit_array => packet_i,
      outFlit    => outChannels(7),
      ready      => ready(7),
      full       => full(7),
      put        => put(7));


end behavioral;

