library IEEE;
use IEEE.std_logic_1164.all;
use IEEE.std_logic_arith.all;
use WORK.types.all;

entity regFile is
  port (
    clk      : in  bit_t;
    reset    : in  bit_t;
    RegWrite : in  bit_t;
    RdReg1   : in  std_logic_vector(4 downto 0);
    RdReg2   : in  std_logic_vector(4 downto 0);
    WrReg    : in  std_logic_vector(4 downto 0);
    RdData1  : out word_t;
    RdData2  : out word_t;
    WrData   : in  word_t);
end regFile;

architecture behaviour of regFile is

  subtype memAddr         is  RANGE 0 TO 31;
  TYPE RegType            IS ARRAY(RegAddr) OF std_logic_vector(31 DOWNTO 0);;
  signal regs: RegType;

begin

  process (clk, reset, regs)
  begin
    if reset = '1' then
      for i in 31 downto 0 loop
        regs(i) <= word_zero;
      end loop;
    elsif falling_edge(clk) then
      if RegWrite = '1' then
          regs(conv_integer(unsigned(WrReg))) <= WrData;
      end if;
    end if;
  end process;

  RdData1 <= regs(conv_integer(unsigned(RdReg1)));
  RdData2 <= regs(conv_integer(unsigned(RdReg2)));			
  
end behaviour;

