
library ieee;
use ieee.std_logic_1164.all;
use ieee.std_logic_arith.all;
use ieee.std_logic_unsigned.all;
use ieee.numeric_std.all;
use work.types.all;

library ieee;
use IEEE.STD_LOGIC_TEXTIO.all;
use STD.TEXTIO.all;

entity testbench_encap_env is
end testbench_encap_env;

architecture testbench_arch of testbench_encap_env is
-- If you get a compiler error on the following line,
-- from the menu do Options->Configuration select VHDL 87

  component encap_environment
    port (
      clk              : in  std_logic;
      reset            : in  std_logic;
      packet_encode_In : in  Packet_Type;
      MCmd_In          : in  MCmd_type;
      MAddr_In         : in  std_logic_vector(MAddr_length-1 downto 0);
      MFlag_In         : in  std_logic_vector(MFlag_length-1 downto 0);
      MData_In         : in  std_logic_vector(MData_length-1 downto 0);
      MDataInfo_In     : in  std_logic_vector(MDataInfo_length-1 downto 0);
      request_phase    : in  std_logic;
      packet_sent_Out  : out std_logic;
      InjID            : in  std_logic_vector(31 downto 0);
      routepath_In     : in  std_logic_vector(routepath_length-1 downto 0);
      outChannels      : out channel_type;
      full             : in  std_logic_vector(num_vc-1 downto 0);
      put              : out std_logic_vector(num_vc-1 downto 0));
  end component;


  signal clk              : std_logic;
  signal reset            : std_logic;
  signal packet_encode_In : Packet_Type;
  signal MCmd_In          : MCmd_type;
  signal MAddr_In         : std_logic_vector (31 downto 0);
  signal MFlag_In         : std_logic_vector (31 downto 0);
  signal MData_In         : std_logic_vector (31 downto 0);
  signal MDataInfo_In     : std_logic_vector (7 downto 0);
  signal request_phase    : std_logic;
  signal packet_sent_Out  : std_logic;
  signal InjID            : std_logic_vector (31 downto 0);
  signal routepath_In     : std_logic_vector (15 downto 0);
  signal outFlit          : std_logic_vector (16 downto 0);
  signal outChSel         : std_logic_vector (2 downto 0);
  signal put              : std_logic_vector (7 downto 0);
  signal full             : std_logic_vector (7 downto 0);
  signal outChannels      : channel_type;
begin
  Encap_env_Unit          : encap_environment
    port map (
      clk              => clk,
      reset            => reset,
      packet_encode_In => packet_encode_In,
      MCmd_In          => MCmd_In,
      MAddr_In         => MAddr_In,
      MFlag_In         => MFlag_In,
      MData_In         => MData_In,
      MDataInfo_In     => MDataInfo_In,
      request_phase    => request_phase,
      packet_sent_Out  => packet_sent_Out,
      InjID            => InjID,
      routepath_In     => routepath_In,
      outChannels      => outChannels,
      full             => full,
      put              => put);



  process                               -- clock process for clk,
  begin
    CLOCK_LOOP : loop
      clk <= transport '0';
      wait for 10 ns;
      clk <= transport '1';
      wait for 10 ns;
      wait for 40 ns;
      clk <= transport '0';
      wait for 40 ns;
    end loop CLOCK_LOOP;
  end process;

  process                               -- Process for clk

  begin
    -- --------------------
    reset            <= transport '1';
    packet_encode_In <= transport Packet_Type'("000");  --0
    MCmd_In          <= transport MCmd_type'("000");  --0
    MAddr_In         <= transport std_logic_vector'("00000000000000000000000000000000");  --0
    MFlag_In         <= transport std_logic_vector'("00000000000000000000000000000000");  --0
    MData_In         <= transport std_logic_vector'("00000000000000000000000000000000");  --0
    MDataInfo_In     <= transport std_logic_vector'("00000000");  --0
    request_phase    <= '0';
    InjID            <= transport std_logic_vector'("00000000000000000000000000000000");  --0
    routepath_In     <= transport std_logic_vector'("0000000000000000");  --0 
   full             <= transport std_logic_vector'("00000000");  --0
    -- --------------------
    wait for 100 ns;                    -- Time=100 ns
    reset            <= transport '0';
    request_phase    <= '1';
    packet_encode_In <= transport Packet_Type'("100");  --4
    MCmd_In          <= transport MCmd_type'("001");  --1
    MAddr_In         <= transport std_logic_vector'("00001001001101001111101000100011");  --934FA23
    MDataInfo_In     <= transport std_logic_vector'("00000101");  --5
    MData_In         <= transport std_logic_vector'("01010110011110000001001000110100");  -- 56781234
    routepath_In     <= transport std_logic_vector'("0101010111000000");  --55C0
    full             <= transport std_logic_vector'("00000000");  --3
    -- --------------------
    wait for 200 ns;
    request_phase    <= '0';
    wait for 100 ns;
    request_phase    <= '1';
    packet_encode_In <= transport Packet_Type'("000");  --0
    MCmd_In          <= transport MCmd_type'("010");  --2
    MAddr_In         <= transport std_logic_vector'("00000001111111111111111100100011");  --1FFFF23
    MFlag_In         <= transport std_logic_vector'("00000000000001000000000000000011");  --40003
    MData_In         <= transport std_logic_vector'("00000000000000100000000000000001");  --20001
    MDataInfo_In     <= transport std_logic_vector'("00000101");  --5
    InjID            <= transport std_logic_vector'("00000000000000000000000001010001");  --51
    routepath_In     <= transport std_logic_vector'("1001011111111111");  --97FF
    full             <= transport std_logic_vector'("00100000");  --20
    -- ------------------------------------------------------------------------
    wait for 200 ns;
    request_phase    <= '0';
    wait for 100 ns;                    -- Time=400 ns
    request_phase    <= '1';
    packet_encode_In <= transport Packet_Type'("110");  --6
    MCmd_In          <= transport MCmd_type'("011");  --3
    MAddr_In         <= transport std_logic_vector'("00010010001101000101011001111000");  --12345678
    MFlag_In         <= transport std_logic_vector'("00000101111111111111110100010000");  --05FFFD10
    MData_In         <= transport std_logic_vector'("00000000000000100000000000000001");  --20001
    MDataInfo_In     <= transport std_logic_vector'("00000101");  --5
    InjID            <= transport std_logic_vector'("00000000000000000000000001010001");  --51
    routepath_In     <= transport std_logic_vector'("1001011111111111");  --97FF
    full             <= transport std_logic_vector'("00100000");  --20
    -- ------------------------------------------------------------------------
    wait for 200 ns;
    request_phase    <= '0';
    wait for 100 ns;                    -- Time=400 ns
    request_phase    <= '1';
    packet_encode_In <= transport Packet_Type'("010");  --6
    MCmd_In          <= transport MCmd_type'("001");  --3
    MAddr_In         <= transport std_logic_vector'("00000001111111111111110100100011");  --01FFFD23
    MFlag_In         <= transport std_logic_vector'("00000101111111111111110100010000");  --05FFFD10
    MData_In         <= transport std_logic_vector'("00000000000000100000000000000001");  --20001
    MDataInfo_In     <= transport std_logic_vector'("00000101");  --5
    InjID            <= transport std_logic_vector'("00000000000000000000000001010001");  --51
    routepath_In     <= transport std_logic_vector'("1001011111111111");  --97FF
    full             <= transport std_logic_vector'("00100000");  --20
    -- --------------------
    wait for 200 ns;
    request_phase    <= '0';
    wait for 100 ns;                    -- Time=500 ns
    full             <= transport std_logic_vector'("00000000");  --0

    wait for 500 ns;
    -- --------------------
    wait for 110 ns;                    -- Time=610 ns
    -- --------------------

  end process;
end testbench_arch;

configuration Encap_cfg of testbench_encap_env is
  for testbench_arch
  end for;
end Encap_cfg;
