library ieee;
use ieee.std_logic_1164.all;
use ieee.std_logic_arith.all;
use ieee.std_logic_unsigned.all;
use ieee.numeric_std.all;
use work.types.all;
use work.ReqE2E_pkg.all;
use work.RouteLookupTable_pkg.all;
use work.ConnIDTable_pkg.all;

library ieee;
use IEEE.STD_LOGIC_TEXTIO.all;
use STD.TEXTIO.all;

entity testbench is
end testbench;

architecture testbench_arch of testbench is
-- If you get a compiler error on the following line,
-- from the menu do Options->Configuration select VHDL 87
  signal clk_i               : std_logic;
  signal reset_i             : std_logic;
  signal MCmd_i              : std_logic_vector(2 downto 0);
  signal MAddr_i             : std_logic_vector(MAddr_length-1 downto 0);
  signal MData_i             : std_logic_vector(MData_length-1 downto 0);
  signal MFlag_i             : std_logic_vector(MFlag_length-1 downto 0);
  signal MReqInfo_i          : std_logic_vector(MReqInfo_length-1 downto 0);
  signal MDataInfo_i         : std_logic_vector(MDataInfo_length-1 downto 0);
  signal SCmdAccept_i        : std_logic;
  signal SResp_i             : SResp_type;
  signal SData_i             : std_logic_vector(SData_length-1 downto 0);
  signal SDataInfo_i         : std_logic_vector(SDataInfo_length-1 downto 0);
  signal MRespAccept_i       : std_logic;
  signal packet_encode_i     : Packet_Type;
  signal MAddr_Out_i         : std_logic_vector(MAddr_length-1 downto 0);
  signal MCmd_Out_i          : MCmd_type;
  signal MFlag_Out_i         : std_logic_vector(MFlag_length-1 downto 0);
  signal MData_Out_i         : std_logic_vector(MData_length-1 downto 0);
  signal MDataInfo_Out_i     : std_logic_vector(MDataInfo_length-1 downto 0);
  signal request_phase_i     : std_logic;
  signal packet_sent_i       : std_logic;
  signal packet_decode_In_i  : Packet_Type;
  signal MCmd_In_i           : MCmd_type;
  signal MAddr_In_i          : std_logic_vector(MAddr_length-1 downto 0);
  signal SResp_In_i          : SResp_type;
  signal SData_In_i          : std_logic_vector(SData_length-1 downto 0);
  signal SDataInfo_In_i      : std_logic_vector(SDataInfo_length-1 downto 0);
  signal Response_arrived_i  : std_logic;
  signal ConnID_address_i    : std_logic_vector(31 downto 0);
  signal injection_channel_i : std_logic_vector(31 downto 0);
  signal MemWrite_i          : std_logic;
  signal MemRead_i           : std_logic;
  signal Dest_SBA_i          : std_logic_vector(7 downto 0);



  signal InjID_i     : std_logic_vector (31 downto 0);
  signal routepath_i : std_logic_vector(15 downto 0);

begin

  ReqE2E_Unit : ReqE2E
    port map (
      clk              => clk_i,
      reset            => reset_i,
      MCmd             => MCmd_i,
      MAddr            => MAddr_i,
      MData            => MData_i,
      MFlag            => MFlag_i,
      MReqInfo         => MReqInfo_i,
      MDataInfo        => MDataInfo_i,
      SCmdAccept       => SCmdAccept_i,
      SResp            => SResp_i,
      SData            => SData_i,
      SDataInfo        => SDataInfo_i,
      MRespAccept      => MRespAccept_i,
      packet_encode    => packet_encode_i,
      MAddr_Out        => MAddr_Out_i,
      MCmd_Out         => MCmd_Out_i,
      MFlag_Out        => MFlag_Out_i,
      MData_Out        => MData_Out_i,
      MDataInfo_Out    => MDataInfo_Out_i,
      request_phase    => request_phase_i,
      packet_sent      => packet_sent_i,
      packet_decode_In => packet_decode_In_i,
      MCmd_In          => MCmd_In_i,
      MAddr_In         => MAddr_In_i,
      SResp_In         => SResp_In_i,
      SData_In         => SData_In_i,
      SDataInfo_In     => SDataInfo_In_i,
      Response_arrived => Response_arrived_i,
      address          => ConnID_address_i,
      write_data       => injection_channel_i,
      MemWrite         => MemWrite_i,
      MemRead          => MemRead_i,
      Dest_SBA         => Dest_SBA_i);

  RouteLookupTable_Unit : RouteLookupTable
    port map (
      address   => Dest_SBA_i,
      read_data => routepath_i);

  ConnIDTable_Unit : ConnIDTable
    port map (
      reset      => reset_i,
      address    => ConnID_address_i,
      write_data => injection_channel_i,
      MemWrite   => MemWrite_i,
      MemRead    => MemRead_i,
      read_data  => InjID_i);


  process                               -- clock process for clk_i,
  begin
    CLOCK_LOOP : loop
      clk_i <= transport '0';
      wait for 10 ns;
      clk_i <= transport '1';
      wait for 10 ns;
      wait for 40 ns;
      clk_i <= transport '0';
      wait for 40 ns;
    end loop CLOCK_LOOP;
  end process;

  process                               -- Process for clk_i

  begin
    -- --------------------
    reset_i            <= transport '1';
    MCmd_i             <= transport std_logic_vector'("000");  --0
    MAddr_i            <= transport std_logic_vector'("00000000000000000000000000000000");  --0
    MData_i            <= transport std_logic_vector'("00000000000000000000000000000000");  --0
    MFlag_i            <= transport std_logic_vector'("00000000000000000000000000000000");  --0
    MReqInfo_i         <= transport std_logic_vector'("00");  --0
    MDataInfo_i        <= transport std_logic_vector'("00000000");  --0
    MRespAccept_i      <= transport '1';
    packet_decode_In_i <= transport std_logic_vector'("000");  --0
    MCmd_In_i          <= transport MCmd_type'("000");  --0
    MAddr_In_i         <= transport std_logic_vector'("00000000000000000000000000000000");  --0
    SResp_In_i         <= transport SResp_type'("00");  --0
    SData_In_i         <= transport std_logic_vector'("00000000000000000000000000000000");  --0
    SDataInfo_In_i     <= transport std_logic_vector'("00000000000000000000000000000000");  --0
    Response_arrived_i <= transport '0';
    packet_sent_i      <= transport '0';
    -- --------------------
    wait for 100 ns;                    -- Time=100 ns
    reset_i            <= transport '0';
    MCmd_i             <= transport std_logic_vector'("001");  --1
    MAddr_i            <= transport std_logic_vector'("00001001001101001111101000100011");  --0934FA23
    MData_i            <= transport std_logic_vector'("01010110011110000001001000110100");  --56781234
    MFlag_i            <= transport std_logic_vector'("00000000000000000000000000000000");  --0
    MReqInfo_i         <= transport std_logic_vector'("00");  --0
    MDataInfo_i        <= transport std_logic_vector'("00000101");  --5
    -- --------------------
    wait for 100 ns;                    -- Time=200 ns
    MCmd_i             <= transport std_logic_vector'("001");  --1
    MAddr_i            <= transport std_logic_vector'("00001001001101001111101000100011");  --0934FA23
    MData_i            <= transport std_logic_vector'("01010110011110000001001000110100");  --56781234
    MFlag_i            <= transport std_logic_vector'("00000000000000000000000000000000");  --0
    MReqInfo_i         <= transport std_logic_vector'("00");  --0
    MDataInfo_i        <= transport std_logic_vector'("00000101");  --5
    -- --------------------
    wait for 100 ns;                    -- Time=300 ns
    MCmd_i             <= transport std_logic_vector'("001");  --1
    MAddr_i            <= transport std_logic_vector'("00001001001101001111101000100011");  --0934FA23
    MData_i            <= transport std_logic_vector'("01010110011110000001001000110100");  --56781234
    MFlag_i            <= transport std_logic_vector'("00000000000000000000000000000000");  --0
    MReqInfo_i         <= transport std_logic_vector'("00");  --0
    MDataInfo_i        <= transport std_logic_vector'("00000101");  --5
    packet_sent_i      <= transport '1';
    -- --------------------
    wait for 100 ns;                    -- Time=400 ns
    MCmd_i             <= transport std_logic_vector'("010");  --2
    MAddr_i            <= transport std_logic_vector'("00000001111111111111111100100011");  --1FFFF23
    MData_i            <= transport std_logic_vector'("00100000000000000001000000000000");  --20001000
    MFlag_i            <= transport std_logic_vector'("01000000000000000011000000000000");  --40003000
    MReqInfo_i         <= transport std_logic_vector'("01");  --1
    MDataInfo_i        <= transport std_logic_vector'("00000101");  --5
    packet_sent_i      <= transport '0';
    -- --------------------
    wait for 100 ns;                    -- Time=500 ns
    MCmd_i             <= transport std_logic_vector'("010");  --2
    MAddr_i            <= transport std_logic_vector'("00000001111111111111111100100011");  --1FFFF23
    MData_i            <= transport std_logic_vector'("00100000000000000001000000000000");  --20001000
    MFlag_i            <= transport std_logic_vector'("01000000000000000011000000000000");  --40003000
    MReqInfo_i         <= transport std_logic_vector'("01");  --1
    MDataInfo_i        <= transport std_logic_vector'("00000101");  --5
    packet_sent_i      <= transport '0';
    -- --------------------
    wait for 100 ns;                    -- Time=500 ns
    MCmd_i             <= transport std_logic_vector'("010");  --2
    MAddr_i            <= transport std_logic_vector'("00000001111111111111111100100011");  --1FFFF23
    MData_i            <= transport std_logic_vector'("00100000000000000001000000000000");  --20001000
    MFlag_i            <= transport std_logic_vector'("01000000000000000011000000000000");  --40003000
    MReqInfo_i         <= transport std_logic_vector'("01");  --1
    MDataInfo_i        <= transport std_logic_vector'("00000101");  --5
    packet_sent_i      <= transport '1';
    -- --------------------
    wait for 100 ns;                    -- Time=600 ns
    MCmd_i             <= transport std_logic_vector'("000");  --0
    MAddr_i            <= transport std_logic_vector'("00000000000000000000000000000000");  --0
    MData_i            <= transport std_logic_vector'("00000000000000000000000000000000");  --0
    MFlag_i            <= transport std_logic_vector'("00000000000000000000000000000000");  --0
    MReqInfo_i         <= transport std_logic_vector'("00");  --0
    MDataInfo_i        <= transport std_logic_vector'("00000000");  --0
    packet_decode_In_i <= transport std_logic_vector'("101");  --5
    MCmd_In_i          <= transport MCmd_type'("001");  --1
    MAddr_In_i         <= transport std_logic_vector'("00000101000100100011010000000000");  --05123400
    SResp_In_i         <= transport SResp_type'("01");  --1
    Response_arrived_i <= transport '1';
    packet_sent_i      <= transport '0';
    -- --------------------
    wait for 100 ns;                    -- Time=700 ns
    packet_sent_i      <= transport '0';
    Response_arrived_i <= transport '0';
    -- --------------------
    wait for 100 ns;                    -- Time=800 ns
    packet_decode_In_i <= transport std_logic_vector'("001");  --1
    MCmd_In_i          <= transport MCmd_type'("000");  --0
    MAddr_In_i         <= transport std_logic_vector'("00000101111111111111110100010000");  --5FFFD10
    SResp_In_i         <= transport SResp_type'("01");  --1
    SData_In_i         <= transport std_logic_vector'("00000000000001100000000000000111");  --00060007
    SDataInfo_In_i     <= transport std_logic_vector'("00000001111111111111110100100011");  --1FFFD23
    Response_arrived_i <= transport '1';
    -- --------------------
    wait for 100 ns;                    -- Time=900 ns
    MCmd_i             <= transport std_logic_vector'("011");  --3
    MAddr_i            <= transport std_logic_vector'("00010010001101000101011001111000");  --12345678
    MData_i            <= transport std_logic_vector'("00000000000000000000000000000000");  --0
    MFlag_i            <= transport std_logic_vector'("00000101111111111111110100010000");  --05FFFD10
    MReqInfo_i         <= transport std_logic_vector'("10");  --2
    MDataInfo_i        <= transport std_logic_vector'("00000101");  --5
    Response_arrived_i <= transport '0';
    -- --------------------
    wait for 100 ns;                    -- Time=1000 ns


    -- --------------------
    wait for 100 ns;                    -- Time=1100 ns
    packet_sent_i      <= transport '1';
    Response_arrived_i <= transport '0';
    -- --------------------
    wait for 100 ns;
    packet_sent_i      <= transport '0';
    -- --------------------
    wait for 100 ns;                    -- Time=1100 ns
    MCmd_i             <= transport std_logic_vector'("001");  --1
    MAddr_i            <= transport std_logic_vector'("00000001111111111111110100100011");  --1FFFD23
    MData_i            <= transport std_logic_vector'("00000000000000000000000000000000");  --0
    MFlag_i            <= transport std_logic_vector'("00000101111111111111110100010000");  --5FFFD10
    MReqInfo_i         <= transport std_logic_vector'("11");  --3
    MDataInfo_i        <= transport std_logic_vector'("00000101");  --5

    packet_decode_In_i <= transport std_logic_vector'("111");  --7
    MCmd_In_i          <= transport MCmd_type'("010");  --2
    MAddr_In_i         <= transport std_logic_vector'("00000000000000000000000000000000");  --0
    SResp_In_i         <= transport SResp_type'("01");  --1
    SData_In_i         <= transport std_logic_vector'("10101100110110100010011100010101");  --ACDA2715
    Response_arrived_i <= transport '1';
    -- --------------------
    wait for 100 ns;                    -- Time=1300 ns

    Response_arrived_i <= transport '0';
    packet_sent_i      <= transport '0';
    -- --------------------
    wait for 100 ns;                    -- Time=1400 ns
    Response_arrived_i <= transport '0';
    packet_sent_i      <= transport '1';
    -- --------------------
    wait for 110 ns;                    -- Time=1510 ns
    MCmd_i             <= transport std_logic_vector'("000");  --0
    MAddr_i            <= transport std_logic_vector'("00000000000000000000000000000000");  --0
    MData_i            <= transport std_logic_vector'("00000000000000000000000000000000");  --0
    MFlag_i            <= transport std_logic_vector'("00000000000000000000000000000000");  --0
    MReqInfo_i         <= transport std_logic_vector'("00");  --0
    MDataInfo_i        <= transport std_logic_vector'("00000000");  --0
    packet_sent_i      <= transport '0';
    -- --------------------
    wait for 110 ns;                    -- Time=1510 ns
    wait for 110 ns;                    -- Time=1510 ns
    packet_decode_In_i <= transport std_logic_vector'("011");  --3
    MCmd_In_i          <= transport MCmd_type'("000");  --0
    MAddr_In_i         <= transport std_logic_vector'("00000101111111111111110100010000");  --5FFFD10
    SResp_In_i         <= transport SResp_type'("01");  --1
    SData_In_i         <= transport std_logic_vector'("00000000000000000000000000000000");  --0
    SDataInfo_In_i     <= transport std_logic_vector'("00000000000000000000000000000000");  --0
    Response_arrived_i <= transport '1';
    wait for 110 ns;                    -- Time=1510 ns
    Response_arrived_i <= transport '0';

  end process;
end testbench_arch;

configuration ReqE2E_cfg of testbench is
  for testbench_arch
  END FOR;
END ReqE2E_cfg;

