library ieee;
use ieee.std_logic_1164.all;
use ieee.std_logic_arith.all;
use ieee.std_logic_unsigned.all;
use ieee.numeric_std.all;
use work.types.all;

library ieee;
use IEEE.STD_LOGIC_TEXTIO.all;
use STD.TEXTIO.all;

entity testbench_slave is
end testbench_slave;

architecture testbench_arch of testbench_slave is
-- If you get a compiler error on the following line,
-- from the menu do Options->Configuration select VHDL 87

  component NASlave
    port (
      clk         : in  std_logic;
      reset       : in  std_logic;
      MCmd        : in  std_logic_vector(MCmd_length-1 downto 0);
      MAddr       : in  std_logic_vector(MAddr_length-1 downto 0);
      MData       : in  std_logic_vector(MData_length-1 downto 0);
      MFlag       : in  std_logic_vector(MFlag_length-1 downto 0);
      MReqInfo    : in  std_logic_vector(MReqInfo_length-1 downto 0);
      MDataInfo   : in  std_logic_vector(MDataInfo_length-1 downto 0);
      SCmdAccept  : out std_logic;
      SResp       : out std_logic_vector(SResp_length-1 downto 0);
      SData       : out std_logic_vector(SData_length-1 downto 0);
      SDataInfo   : out std_logic_vector(SDataInfo_length-1 downto 0);
      MRespAccept : in  std_logic;
      empty       : in  std_logic_vector(num_vc-1 downto 0);
      get         : out std_logic_vector(num_vc-1 downto 0);
      inChannels  : in  channel_type;
      full        : in  std_logic_vector(num_vc-1 downto 0);
      put         : out std_logic_vector(num_vc-1 downto 0);
      outChannels : out channel_type);
  end component;

  signal clk_i         : std_logic;
  signal reset_i       : std_logic;
  signal MCmd_i        : std_logic_vector(MCmd_length-1 downto 0);
  signal MAddr_i       : std_logic_vector(MAddr_length-1 downto 0);
  signal MData_i       : std_logic_vector(MData_length-1 downto 0);
  signal MFlag_i       : std_logic_vector(MFlag_length-1 downto 0);
  signal MReqInfo_i    : std_logic_vector(MReqInfo_length-1 downto 0);
  signal MDataInfo_i   : std_logic_vector(MDataInfo_length-1 downto 0);
  signal SCmdAccept_i  : std_logic;
  signal SResp_i       : std_logic_vector(SResp_length-1 downto 0);
  signal SData_i       : std_logic_vector(SData_length-1 downto 0);
  signal SDataInfo_i   : std_logic_vector(SDataInfo_length-1 downto 0);
  signal MRespAccept_i : std_logic;
  signal empty_i       : std_logic_vector(num_vc-1 downto 0);
  signal get_i         : std_logic_vector(num_vc-1 downto 0);
  signal inChannels_i  : channel_type;
  signal full_i        : std_logic_vector(num_vc-1 downto 0);
  signal put_i         : std_logic_vector(num_vc-1 downto 0);
  signal outChannels_i : channel_type;
begin


  Slave_Unit : NASlave
    port map (
      clk         => clk_i,
      reset       => reset_i,
      MCmd        => MCmd_i,
      MAddr       => MAddr_i,
      MData       => MData_i,
      MFlag       => MFlag_i,
      MReqInfo    => MReqInfo_i,
      MDataInfo   => MDataInfo_i,
      SCmdAccept  => SCmdAccept_i,
      SResp       => SResp_i,
      SData       => SData_i,
      SDataInfo   => SDataInfo_i,
      MRespAccept => MRespAccept_i,
      empty       => empty_i,
      get         => get_i,
      inChannels  => inChannels_i,
      full        => full_i,
      put         => put_i,
      outChannels => outChannels_i);

  process                               -- clock process for clk_i,
  begin
    CLOCK_LOOP : loop
      clk_i <= transport '0';
      wait for 10 ns;
      clk_i <= transport '1';
      wait for 10 ns;
      wait for 40 ns;
      clk_i <= transport '0';
      wait for 40 ns;
    end loop CLOCK_LOOP;
  end process;

  process                               -- Process for clk_i

  begin
    -- --------------------
    reset_i       <= transport '1';
    MCmd_i        <= transport std_logic_vector'("000");  --0
    MAddr_i       <= transport std_logic_vector'("00000000000000000000000000000000");  --0
    MData_i       <= transport std_logic_vector'("00000000000000000000000000000000");  --0
    MFlag_i       <= transport std_logic_vector'("00000000000000000000000000000000");  --0
    MReqInfo_i    <= transport std_logic_vector'("00");  --0
    MDataInfo_i   <= transport std_logic_vector'("00000000");  --0
    MRespAccept_i <= transport '1';
    full_i          <= transport std_logic_vector'("00000000");  --0
    empty_i         <= transport std_logic_vector'("11111111");  --0
    inChannels_i(0) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(1) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(2) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(3) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(4) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(5) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(6) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(7) <= transport std_logic_vector'("00000000000000000");  --0  
    -- --------------------
    wait for 100 ns;                    -- Time=100 ns
    reset_i       <= transport '0';
    MAddr_i       <= transport std_logic_vector'("00001001001101001111101000100011");  --0934FA23
    MCmd_i        <= transport std_logic_vector'("001");  --1
    MDataInfo_i   <= transport std_logic_vector'("00000101");  --5
    MData_i       <= transport std_logic_vector'("01010110011110000001001000110100");  --56781234
    MFlag_i       <= transport std_logic_vector'("00000000000000000000000000000000");  --0
    MReqInfo_i    <= transport std_logic_vector'("00");  --0
    full_i          <= transport std_logic_vector'("00000000");  --0   
    -- --------------------
    wait for 400 ns;
    -- should receive SCmdAccept in 2 cycles
    MAddr_i       <= transport std_logic_vector'("00000001111111111111110100100011");  --01FFFD23
    MCmd_i        <= transport std_logic_vector'("010");  --2
    MDataInfo_i   <= transport std_logic_vector'("00000101");  --5
    MData_i       <= transport std_logic_vector'("00100000000000000001000000000000");  --20001000
    MFlag_i       <= transport std_logic_vector'("01000000000000000011000000000000");  --40003000
    MReqInfo_i    <= transport std_logic_vector'("01");  --1
    full_i          <= transport std_logic_vector'("00000000");  --0  
    -- --------------------
    wait for 500 ns;
    -- should receive SCmdAccept in 2 cycles
    MCmd_i        <= transport std_logic_vector'("000");  --0
    MAddr_i       <= transport std_logic_vector'("00000000000000000000000000000000");  --0
    MData_i       <= transport std_logic_vector'("00000000000000000000000000000000");  --0
    MFlag_i       <= transport std_logic_vector'("00000000000000000000000000000000");  --0
    MReqInfo_i    <= transport std_logic_vector'("00");  --0
    MDataInfo_i   <= transport std_logic_vector'("00000000");  --0
    MRespAccept_i <= transport '1';
    full_i          <= transport std_logic_vector'("00000000");  --0
    empty_i         <= transport std_logic_vector'("11111101");  --FD
    inChannels_i(0) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(1) <= transport std_logic_vector'("01111001000000000");  --F200
    inChannels_i(2) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(3) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(4) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(5) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(6) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(7) <= transport std_logic_vector'("00000000000000000");  --0
    -- --------------------
    wait for 100 ns;                    -- Time=400 ns
    empty_i         <= transport std_logic_vector'("11111101");  --FD
    inChannels_i(0) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(1) <= transport std_logic_vector'("01111110100010000");  --FD10
    inChannels_i(2) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(3) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(4) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(5) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(6) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(7) <= transport std_logic_vector'("00000000000000000");  --0
    -- --------------------
    wait for 100 ns;                    -- Time=400 ns
    empty_i         <= transport std_logic_vector'("11111101");  --FD
    inChannels_i(0) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(1) <= transport std_logic_vector'("00001000011000000");  --10C0
    inChannels_i(2) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(3) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(4) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(5) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(6) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(7) <= transport std_logic_vector'("00000000000000000");  --0
    -- --------------------
    wait for 100 ns;                    -- Time=500 ns
    empty_i         <= transport std_logic_vector'("11111101");  --FD
    inChannels_i(0) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(1) <= transport std_logic_vector'("00000010111111111");  --05FF
    inChannels_i(2) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(3) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(4) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(5) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(6) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(7) <= transport std_logic_vector'("00000000000000000");  --0
    -- --------------------
    wait for 100 ns;                    -- Time=500 ns
    empty_i         <= transport std_logic_vector'("11111101");  --FD
    inChannels_i(0) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(1) <= transport std_logic_vector'("00100000000000000");  --4000
    inChannels_i(2) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(3) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(4) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(5) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(6) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(7) <= transport std_logic_vector'("00000000000000000");  --0
    -- --------------------
    wait for 100 ns;                    -- Time=600 ns
    empty_i         <= transport std_logic_vector'("11111101");  --FD
    inChannels_i(0) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(1) <= transport std_logic_vector'("01111110100100011");  --FD23
    inChannels_i(2) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(3) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(4) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(5) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(6) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(7) <= transport std_logic_vector'("00000000000000000");  --0
    -- --------------------
    wait for 100 ns;                    -- Time=700 ns
    empty_i         <= transport std_logic_vector'("11111100");  --FD
    inChannels_i(0) <= transport std_logic_vector'("01111111110000000");  --FF80
    inChannels_i(1) <= transport std_logic_vector'("00000000111111111");  --01FF
    inChannels_i(2) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(3) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(4) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(5) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(6) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(7) <= transport std_logic_vector'("00000000000000000");  --0
    -- --------------------
    wait for 100 ns;                    -- Time=800 ns
    empty_i         <= transport std_logic_vector'("11111100");  --FD
    inChannels_i(0) <= transport std_logic_vector'("01111111110000000");  --FF80
    inChannels_i(1) <= transport std_logic_vector'("00000000001010100");  --0054
    inChannels_i(2) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(3) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(4) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(5) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(6) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(7) <= transport std_logic_vector'("00000000000000000");  --0
    -- --------------------
    wait for 100 ns;                    -- Time=900 ns
    empty_i         <= transport std_logic_vector'("11111100");  --FD
    inChannels_i(0) <= transport std_logic_vector'("01111111110000000");  --FF80
    inChannels_i(1) <= transport std_logic_vector'("10000000000000000");  --0000
    inChannels_i(2) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(3) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(4) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(5) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(6) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(7) <= transport std_logic_vector'("00000000000000000");  --0
    -- --------------------
    wait for 100 ns;                    -- Time=1000 ns
    empty_i         <= transport std_logic_vector'("11111110");  --FD
    inChannels_i(0) <= transport std_logic_vector'("01111111110000000");  --FF80
    inChannels_i(1) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(2) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(3) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(4) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(5) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(6) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(7) <= transport std_logic_vector'("00000000000000000");  --0
    -- --------------------
    wait for 100 ns;                    -- Time=1100 ns
    empty_i         <= transport std_logic_vector'("11111110");  --FD
    inChannels_i(0) <= transport std_logic_vector'("00011010000000000");  --3400
    inChannels_i(1) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(2) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(3) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(4) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(5) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(6) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(7) <= transport std_logic_vector'("00000000000000000");  --0
    -- --------------------
    wait for 100 ns;
    empty_i         <= transport std_logic_vector'("11111110");  --FD
    inChannels_i(0) <= transport std_logic_vector'("00000000010010000");  --0090
    inChannels_i(1) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(2) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(3) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(4) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(5) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(6) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(7) <= transport std_logic_vector'("00000000000000000");  --0
    -- --------------------
    wait for 100 ns;                    -- Time=1100 ns
    MCmd_i        <= transport std_logic_vector'("011");  --3
    MAddr_i       <= transport std_logic_vector'("00000001001000110100010101100111");  --01234567
    MData_i       <= transport std_logic_vector'("00000000000000000000000000000000");  --0
    MFlag_i       <= transport std_logic_vector'("00000101111111111111110100010000");  --5FFFD10
    MReqInfo_i    <= transport std_logic_vector'("10");  --2
    MDataInfo_i   <= transport std_logic_vector'("00000101");  --5
    full_i          <= transport std_logic_vector'("00100000");  --0 
    empty_i         <= transport std_logic_vector'("11111110");  --FD
    inChannels_i(0) <= transport std_logic_vector'("00000010100010010");  --0512
    inChannels_i(1) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(2) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(3) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(4) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(5) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(6) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(7) <= transport std_logic_vector'("00000000000000000");  --0
    -- --------------------
    wait for 100 ns;                    -- Time=1300 ns
    full_i          <= transport std_logic_vector'("00100000");  --0
    empty_i         <= transport std_logic_vector'("11111110");  --FD
    inChannels_i(0) <= transport std_logic_vector'("10100000000000000");  --4000
    inChannels_i(1) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(2) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(3) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(4) <= transport std_logic_vector'("00000000000000000");  --
    inChannels_i(5) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(6) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(7) <= transport std_logic_vector'("00000000000000000");  --0
    -- --------------------
    wait for 100 ns;                    -- Time=1300 ns
    full_i          <= transport std_logic_vector'("00100000");  --0
    empty_i         <= transport std_logic_vector'("11111111");  --FD
    inChannels_i(0) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(1) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(2) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(3) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(4) <= transport std_logic_vector'("00000000000000000");  --
    inChannels_i(5) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(6) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(7) <= transport std_logic_vector'("00000000000000000");  --0
    -- --------------------
    wait for 100 ns;                    -- Time=1400 ns
    full_i          <= transport std_logic_vector'("00000000");  --0    
    -- --------------------
    wait for 100 ns;                    -- Time=1500 ns
    MCmd_i        <= transport std_logic_vector'("000");  --0
    MAddr_i       <= transport std_logic_vector'("00000000000000000000000000000000");  --0
    MData_i       <= transport std_logic_vector'("00000000000000000000000000000000");  --0
    MFlag_i       <= transport std_logic_vector'("00000000000000000000000000000000");  --0
    MReqInfo_i    <= transport std_logic_vector'("00");  --0
    MDataInfo_i   <= transport std_logic_vector'("00000000");  --0
    -- --------------------
    wait for 100 ns;                    -- Time=1600 ns
    empty_i         <= transport std_logic_vector'("11101111");  --FD
    inChannels_i(0) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(1) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(2) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(3) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(4) <= transport std_logic_vector'("00000110000000000");  --0C00
    inChannels_i(5) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(6) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(7) <= transport std_logic_vector'("00000000000000000");  --0
    -- -------------------- 
    wait for 100 ns;                    -- Time=1510 ns
    empty_i         <= transport std_logic_vector'("11101111");  --FD
    inChannels_i(0) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(1) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(2) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(3) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(4) <= transport std_logic_vector'("00010011100010101");  --2715
    inChannels_i(5) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(6) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(7) <= transport std_logic_vector'("00000000000000000");  --0
    -- --------------------    
    wait for 100 ns;                    -- Time=1510 ns
    MCmd_i        <= transport std_logic_vector'("001");  --1
    MAddr_i       <= transport std_logic_vector'("00000001111111111111110100100011");  --01FFFD23
    MData_i       <= transport std_logic_vector'("00000000000000000000000000000000");  --0
    MFlag_i       <= transport std_logic_vector'("00000101111111111111110100010000");  --5FFFD10
    MReqInfo_i    <= transport std_logic_vector'("11");  --3
    MDataInfo_i   <= transport std_logic_vector'("00000101");  --5
    full_i          <= transport std_logic_vector'("00000000");  --0 
    empty_i         <= transport std_logic_vector'("11101111");  --FD
    inChannels_i(0) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(1) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(2) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(3) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(4) <= transport std_logic_vector'("11010110011011010");  --ACDA
    inChannels_i(5) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(6) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(7) <= transport std_logic_vector'("00000000000000000");  --0
    -- --------------------    
    wait for 100 ns;                    -- Time=1510 ns
    empty_i         <= transport std_logic_vector'("11110111");  --FD
    inChannels_i(0) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(1) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(2) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(3) <= transport std_logic_vector'("01111001000000000");  --F200
    inChannels_i(4) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(5) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(6) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(7) <= transport std_logic_vector'("00000000000000000");  --0
    -- --------------------    
    wait for 100 ns;                    -- Time=1510 ns
    empty_i         <= transport std_logic_vector'("11110111");  --FD
    inChannels_i(0) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(1) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(2) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(3) <= transport std_logic_vector'("01111110100100000");  --FD10
    inChannels_i(4) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(5) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(6) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(7) <= transport std_logic_vector'("00000000000000000");  --0
    -- --------------------    
    wait for 100 ns;                    -- Time=1510 ns
    empty_i         <= transport std_logic_vector'("11110111");  --FD
    inChannels_i(0) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(1) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(2) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(3) <= transport std_logic_vector'("00000000011000000");  --00C0
    inChannels_i(4) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(5) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(6) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(7) <= transport std_logic_vector'("00000000000000000");  --0
    -- --------------------    
    wait for 100 ns;                    -- Time=1510 ns
    MCmd_i        <= transport std_logic_vector'("000");  --0
    MAddr_i       <= transport std_logic_vector'("00000000000000000000000000000000");  --0
    MData_i       <= transport std_logic_vector'("00000000000000000000000000000000");  --0
    MFlag_i       <= transport std_logic_vector'("00000000000000000000000000000000");  --0
    MReqInfo_i    <= transport std_logic_vector'("00");  --0
    MDataInfo_i   <= transport std_logic_vector'("00000000");  --0
    MRespAccept_i <= transport '1';
    full_i          <= transport std_logic_vector'("00000000");  --0
    empty_i         <= transport std_logic_vector'("11110111");  --FD
    inChannels_i(0) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(1) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(2) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(3) <= transport std_logic_vector'("00000010111111111");  --05FF
    inChannels_i(4) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(5) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(6) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(7) <= transport std_logic_vector'("00000000000000000");  --0
    -- --------------------    
    wait for 100 ns;                    -- Time=1510 ns
    empty_i         <= transport std_logic_vector'("11110111");  --FD
    inChannels_i(0) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(1) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(2) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(3) <= transport std_logic_vector'("10100000000000000");  --4000
    inChannels_i(4) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(5) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(6) <= transport std_logic_vector'("00000000000000000");  --0
    inChannels_i(7) <= transport std_logic_vector'("00000000000000000");  --0
    -- --------------------
    wait for 910 ns;                    -- Time=4710 ns
    -- --------------------                                                                       
  end process;
end testbench_arch;

configuration ReqE2E_cfg of testbench_slave is
  for testbench_arch
  end for;
end ReqE2E_cfg;

